==> v1.4.tar.gz: le-chat-php/lang_de.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - German translation
*
* Copyright (C) 2015 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

$I=array(
	'nodb' => 'Keine Verbindung zur Datenbank!',
	'nodbsetup' => 'Keine Verbindung zur Datenbank, bitte erstelle eine Datenbank und bearbeite das Skript, um die korrekte Datenbank mit angegebenem Benutzernamen und Passwort zu benutzen.',
	'changelang' => 'Sprache ändern:',
	'expire' => 'Ungültige/abgelaufene Sitzung',
	'kicked' => 'Rausgeschmissen!',
	'invalnick' => 'Ungültiger Nickname (Maximal %d Zeichen, keine Sonderzeichen erlaubt)',
	'invalpass' => 'Ungültiges Passwort (Mindestens %d Zeichen)',
	'noconfirm' => 'Passwordbestätigung stimmt nicht überein!',
	'incorregex' => 'Ungültiger regulärer Ausdruck!',
	'bottom' => 'Unten',
	'top' => 'Oben',
	'choose' => '(auswählen)',
	'setup' => 'Chat Einrichtung',
	'init' => 'Erste Einrichtung',
	'sulogin' => 'Superadmin Anmeldung',
	'sunick' => 'Superadmin Nickname:',
	'supass' => 'Superadmin Passwort:',
	'suconfirm' => 'Passowrt bestätigen:',
	'susuccess' => 'Erfolgreich registriert!',
	'initbtn' => 'Chat initalisieren',
	'initdbexist' => 'Datenbanktabellen existieren bereits! Um vortzufahren, musst du diese Tabellen zuerst manuell löschen.',
	'initsuexist' => 'Ein Superadmin existiert bereits!',
	'initgosetup' => 'Zur Einrichtungsseite gehen',
	'dbupdate' => 'Datenbank erfolgreich aktualisiert!',
	'sysmessages' => 'Systemnachrichten',
	'msgenter' => 'Eintritt',
	'msgexit' => 'Verlassen',
	'msgmemreg' => 'Mitglied registriert',
	'msgsureg' => 'Anwerber registriert',
	'msgkick' => 'Rauswurf',
	'msgmultikick' => 'Mehrere rausgeworfen',
	'msgallkick' => 'Alle rausgeworfen',
	'msgclean' => 'Raum geleert',
	'nick' => 'Nickname:',
	'pass' => 'Passwort:',
	'login' => 'Anmelden',
	'admfunc' => 'Administrative Funktionen',
	'allguests' => 'Alle Gäste',
	'cleanmsgs' => 'Nachrichten löschen',
	'room' => 'Gesamten Raum',
	'selection' => 'Auswahl',
	'clean' => 'Löschen',
	'kickchat' => '<b>Teilnehmer rausschmeißen</b> (%d Minuten)',
	'kickmsg' => 'Begründung:',
	'kickpurge' => 'Nachrichten löschen',
	'kick' => 'Rausschmeißen',
	'logoutinact' => 'Inaktive Teilnehmer abmelden',
	'logout' => 'Abmelden',
	'viewsess' => 'Aktive Sitzungen anzeigen',
	'view' => 'Anzeigen',
	'filter' => 'Filter',
	'guestacc' => 'Gastzugriff ändern',
	'guestallow' => 'Erlauben',
	'guestwait' => 'Mit Warteraum erlauben',
	'adminallow' => 'Moderator-Erlaubnis benötigen',
	'guestdisallow' => 'Verweigern',
	'addsuguest' => 'Anwerber hinzufügen',
	'register' => 'Registrieren',
	'admmembers' => 'Mitglieder',
	'memdel' => 'Aus der Datenbank löschen',
	'memdeny' => 'Zugriff verweigern (!)',
	'memsuguest' => 'Zu Anwerber machen (G)',
	'memreg' => 'Zu regulärem Mitglied machen',
	'memmod' => 'Zu Moderator machen (M)',
	'memsumod' => 'Zu Supermod machen (M)',
	'memadm' => 'Zu Admin machen (A)',
	'change' => 'Ändern',
	'regguest' => 'Gast registrieren',
	'regmem' => 'Mitglied registrieren',
	'sessact' => 'Aktive Sitzungen',
	'sessnick' => 'Nickname',
	'sesstimeout' => 'Ablauf in',
	'sessua' => 'User-Agent',
	'fid' => 'Filter ID:',
	'match' => 'Entsprechung',
	'replace' => 'Ersetzen',
	'allowpm' => 'In PM zulassen',
	'regex' => 'Regex',
	'apply' => 'Anwenden',
	'newfilter' => 'Neuer Filter:',
	'add' => 'Hinzufügen',
	'noframes' => 'Dieser Chat benutzt <b>Frames</b>. Bitte aktiviere Frames in deinem Browser oder benutze einen dafür geeigneten!',
	'delselmes' => 'Ausgewählte Nachrichten löschen',
	'staffnotes' => 'Moderatornotizen',
	'adminnotes' => 'Adminnotizen',
	'notessaved' => 'Notizen gespeichert!',
	'lastedited' => 'Zuletzt bearbeitet von %1$s um %2$s',
	'savenotes' => 'Notizen speichern',
	'waitingroom' => 'Warteraum',
	'waittext' => 'Wilkommen %1$s, deine Anmeldung wurde verzögert, du kannst den Chat in %2$d Sekunden benutzen.',
	'admwaittext' => 'Wilkommen %1$s, deine Anmeldung wurde verzögert, du kannst den Chat benutzen, sobald ein Moderator dich hereinlässt.',
	'waitreload' => 'Wenn diese Seite sich nicht alle %d Sekunden aktualisiert, benutze den Knopf unten, um die Seite manuell neu zu laden!',
	'reload' => 'Aktualisieren',
	'rules' => 'Regeln',
	'talkto' => 'Senden an',
	'toall' => 'Alle Teilnehmer',
	'tomem' => 'Nur Mitglieder',
	'tostaff' => 'Nur Moderatoren',
	'toadmin' => 'Nur Admins',
	'alsopurge' => 'Auch Nachrichten löschen',
	'dellast' => 'Letzte Nachricht löschen',
	'delall' => 'Alle Nachrichten löschen',
	'switchsingle' => 'Zu Einzel-Zeile wechseln',
	'switchmulti' => 'Zu Mehrfach-Zeilen wechseln',
	'help' => 'Hilfe',
	'helpguest' => 'Alle Funktionen sollten recht selbsterklärend sein, benutze einfach die Knöpfe. In deinem Profil kannst du die Aktualisierungsrate, Schriftfarbe und deine gewünschte Postboxgröße anpassen.<br><u>Hinweis:</u> Dies ist ein Chat, wenn du also nichts schreibst, wirst du automatisch nach einiger Zeit abgemaldet.',
	'helpembed' => 'Wenn du ein Bild einbetten möchtest, füge einfach ein [img] vor die Adresse deines Bildes. Beispiel: [img]http://example.com/images/file.jpg bettet das Bild in deinen Beitrag ein. Für Videos gilt das gleiche, nur mit [vid] davor.',
	'helpmem' => 'Mitglieder: Du wirst einige zusätzliche Optionen in deinem Profil haben. Du kannst deine Schriftart ändern und du kannst dein Passwort jederzeit ändern.',
	'helpmod' => 'Moderatoren: Achte auf den Admin-Knof unten. Er bringt eine Seite auf, auf der du Nachrichten löschen kannst, Teilnehmer rausschmeißen kannst, alle aktive Sitzungen anzeigen lassen kannst und den Gastzugriff deaktivieren kannst, falls dies nötig sein sollte.',
	'helpadm' => 'Admins: Du wirst zusätzlich in der Lage sein Gäste zu registrieren, Mitglieder zu verwalten und neue Nicknanem zu registrieren, ohne dass sie im Raum sind.',
	'profile' => 'Dein Profil',
	'ignore' => 'Ignorieren',
	'unignore' => 'Nicht mehr ignorieren',
	'refreshrate' => 'Aktualisierungsrate (20-150 Sekunden)',
	'fontcolour' => 'Schriftfarbe',
	'viewexample' => 'Beispiele anzeigen',
	'bgcolour' => 'Hintergrundfarbe',
	'fontface' => 'Schriftart',
	'roomdefault' => 'Raumstandard',
	'bold' => 'Fett',
	'italic' => 'Kursiv',
	'fontexample' => 'Beispiel für deine gewählte Schrift',
	'timestamps' => 'Zeitstempel anzeigen',
	'embed' => 'Bilder/Videos einbetten',
	'pbsize' => 'Postboxgröße',
	'nbsize' => 'Notizboxgröße',
	'width' => 'Breite:',
	'height' => 'Höhe:',
	'changepass' => 'Passwort ändern',
	'oldpass' => 'Altes Passwort:',
	'newpass' => 'Neues Passwort:',
	'confirmpass' => 'Passwort bestätigen:',
	'savechanges' => 'Änderungen speichern',
	'reloadpb' => 'Postbox neu laden',
	'reloadmsgs' => 'Nachrichten neu laden',
	'chgprofile' => 'Profil ändern',
	'adminbtn' => 'Admin',
	'admnotes' => 'Adminnotizen',
	'notes' => 'Notizen',
	'clone' => 'Klonen',
	'randh' => 'Regeln & Hilfe',
	'exit' => 'Chat verlassen',
	'bye' => 'Auf Wiedersehen %s, besuche uns bald wieder!',
	'colourtable' => 'Farbtabelle',
	'backtoprofile' => 'Zurück zu deinem Profil',
	'copy' => 'Kopiere:',
	'choosecol' => 'Gast, such dir eine Farbe aus:',
	'randomcol' => 'Zufällige Farbe',
	'enter' => 'Chat beitreten',
	'error' => 'Fehler:',
	'members' => 'Mitglieder:',
	'guests' => 'Gäste:',
	'approveguests' => '%d neue Gäste zum Hereinlassen',
	'allowchecked' => 'Ausgewählte erlauben',
	'allowall' => 'Alle erlauben',
	'denychecked' => 'Ausgewählte abweisen',
	'denyall' => 'Alle abweisen',
	'denymessage' => 'Nachricht an abgewiesene senden:',
	'butallowdeny' => 'Senden',
	'waitempty' => 'Keine weiteren Beitrittsanfragen zu akzeptieren.',
	'wrongcaptcha' => 'Falsches Captcha',
	'captchatime' => 'Captcha wurde bereits verwendet oder ist abgelaufen.',
	'noguests' => 'Keine Gäste zugelassen!',
	'curchat' => 'Zurzeit sind %d Teilnehmer im Raum:',
	'cantreg' => '%s kann nicht registriert werden',
	'alreadyreged' => '%s ist bereits registriert.',
	'successreg' => '%s wurde erfolgreich registriert.',
	'cantchgstat' => 'Der Status von %s kann nicht geändert werden.',
	'succdel' => '%s wurde erfolgriech aus der Datenbank gelöscht.',
	'succchg' => 'Status of %s successfully changed.',
	'wrongpass' => 'Falsches Passwort!',
	'succprofile' => 'Dein Profil wurde erfolgreich gespeichert.',
	'backtologin' => 'Zurück zur Anmeldeseite.',
	'backtochat' => 'Zurück zum Chat.',
	'Beige' => 'Beige',
	'Black' => 'Schwarz',
	'Blue' => 'Blau',
	'BlueViolet' => 'Blauviolett',
	'Brown' => 'Braun',
	'Cyan' => 'Türkis',
	'DarkBlue' => 'Dunkelblau',
	'DarkGreen' => 'Dunkelgrün',
	'DarkRed' => 'Dunkelrot',
	'DarkViolet' => 'Dunkelviolett',
	'DeepSkyBlue' => 'Himmelsblau',
	'Gold' => 'Gold',
	'Grey' => 'Grau',
	'Green' => 'Grün',
	'HotPink' => 'Pink',
	'Indigo' => 'Indigoblau',
	'LightBlue' => 'Hellblau',
	'LightGreen' => 'Hellgrün',
	'LimeGreen' => 'Lindgrün',
	'Magenta' => 'Magenta',
	'Olive' => 'Oliv',
	'Orange' => 'Orange',
	'OrangeRed' => 'Orangerot',
	'Purple' => 'Lila',
	'Red' => 'Rot',
	'RoyalBlue' => 'Königsblau',
	'SeaGreen' => 'Seegrün',
	'Sienna' => 'Siena',
	'Silver' => 'Silber',
	'Tan' => 'Hellbraun',
	'Teal' => 'Blaugrün',
	'Violet' => 'Violett',
	'White' => 'Weiß',
	'Yellow' => 'Gelb',
	'YellowGreen' => 'Gelbgrün',
	'contributors' => 'Mitwirkende'
);
?>

==> v1.7.tar.gz: le-chat-php/lang_de.php <==
<?php
/*
* LE CHAT-PHP - a PHP Chat based on LE CHAT - German translation
*
* Copyright (C) 2015 Daniel Winzen <d@winzen4.de>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

$I=array(
	'nodb' => 'Keine Verbindung zur Datenbank!',
	'nodbsetup' => 'Keine Verbindung zur Datenbank, bitte erstelle eine Datenbank und bearbeite das Skript, um die korrekte Datenbank mit angegebenem Benutzernamen und Passwort zu benutzen.',
	'changelang' => 'Sprache ändern:',
	'expire' => 'Ungültige/abgelaufene Sitzung',
	'kicked' => 'Rausgeschmissen!',
	'invalnick' => 'Ungültiger Nickname (Maximal %d Zeichen, keine Sonderzeichen erlaubt)',
	'invalpass' => 'Ungültiges Passwort (Mindestens %d Zeichen)',
	'noconfirm' => 'Passwordbestätigung stimmt nicht überein!',
	'incorregex' => 'Ungültiger regulärer Ausdruck!',
	'bottom' => 'Unten',
	'top' => 'Oben',
	'choose' => '(auswählen)',
	'setup' => 'Chat Einrichtung',
	'init' => 'Erste Einrichtung',
	'sulogin' => 'Superadmin Anmeldung',
	'sunick' => 'Superadmin Nickname:',
	'supass' => 'Superadmin Passwort:',
	'suconfirm' => 'Passowrt bestätigen:',
	'susuccess' => 'Erfolgreich registriert!',
	'initbtn' => 'Chat initalisieren',
	'initdbexist' => 'Datenbanktabellen existieren bereits! Um vortzufahren, musst du diese Tabellen zuerst manuell löschen.',
	'initsuexist' => 'Ein Superadmin existiert bereits!',
	'initgosetup' => 'Zur Einrichtungsseite gehen',
	'dbupdate' => 'Datenbank erfolgreich aktualisiert!',
	'sysmessages' => 'Systemnachrichten',
	'msgenter' => 'Eintritt',
	'msgexit' => 'Verlassen',
	'msgmemreg' => 'Mitglied registriert',
	'msgsureg' => 'Anwerber registriert',
	'msgkick' => 'Rauswurf',
	'msgmultikick' => 'Mehrere rausgeworfen',
	'msgallkick' => 'Alle rausgeworfen',
	'msgclean' => 'Raum geleert',
	'dateformat' => '<a target="_blank" href="http://php.net/manual/de/function.date.php#refsect1-function.date-parameters">Date formating</a>',
	'nick' => 'Nickname:',
	'pass' => 'Passwort:',
	'globalloginpass' => 'Globales Passwort:',
	'login' => 'Anmelden',
	'admfunc' => 'Administrative Funktionen',
	'allguests' => 'Alle Gäste',
	'cleanmsgs' => 'Nachrichten löschen',
	'room' => 'Gesamten Raum',
	'selection' => 'Auswahl',
	'clean' => 'Löschen',
	'kickchat' => '<b>Teilnehmer rausschmeißen</b> (%d Minuten)',
	'kickmsg' => 'Begründung:',
	'kickpurge' => 'Nachrichten löschen',
	'kick' => 'Rausschmeißen',
	'logoutinact' => 'Inaktive Teilnehmer abmelden',
	'logout' => 'Abmelden',
	'viewsess' => 'Aktive Sitzungen anzeigen',
	'view' => 'Anzeigen',
	'filter' => 'Filter',
	'guestacc' => 'Gastzugriff ändern',
	'guestallow' => 'Erlauben',
	'guestwait' => 'Mit Warteraum erlauben',
	'adminallow' => 'Moderator-Erlaubnis benötigen',
	'globalpass' => 'Mit globalem Passwort erlauben',
	'memberglobalpass' => 'Nur Mitglieder mit globalem Passwort',
	'guestdisallow' => 'Nur Mitglieder',
	'addsuguest' => 'Anwerber hinzufügen',
	'register' => 'Registrieren',
	'admmembers' => 'Mitglieder',
	'memdel' => 'Aus der Datenbank löschen',
	'memdeny' => 'Zugriff verweigern (!)',
	'memsuguest' => 'Zu Anwerber machen (G)',
	'memreg' => 'Zu regulärem Mitglied machen',
	'memmod' => 'Zu Moderator machen (M)',
	'memsumod' => 'Zu Supermod machen (M)',
	'memadm' => 'Zu Admin machen (A)',
	'change' => 'Ändern',
	'regguest' => 'Gast registrieren',
	'regmem' => 'Mitglied registrieren',
	'sessact' => 'Aktive Sitzungen',
	'sessnick' => 'Nickname',
	'sesstimeout' => 'Ablauf in',
	'sessua' => 'User-Agent',
	'fid' => 'Filter ID:',
	'match' => 'Entsprechung',
	'replace' => 'Ersetzen',
	'allowpm' => 'In PM zulassen',
	'regex' => 'Regex',
	'apply' => 'Anwenden',
	'newfilter' => 'Neuer Filter:',
	'add' => 'Hinzufügen',
	'noframes' => 'Dieser Chat benutzt <b>Frames</b>. Bitte aktiviere Frames in deinem Browser oder benutze einen dafür geeigneten!',
	'delselmes' => 'Ausgewählte Nachrichten löschen',
	'staffnotes' => 'Moderatornotizen',
	'adminnotes' => 'Adminnotizen',
	'notessaved' => 'Notizen gespeichert!',
	'lastedited' => 'Zuletzt bearbeitet von %1$s um %2$s',
	'savenotes' => 'Notizen speichern',
	'waitingroom' => 'Warteraum',
	'waittext' => 'Wilkommen %1$s, deine Anmeldung wurde verzögert, du kannst den Chat in %2$d Sekunden benutzen.',
	'admwaittext' => 'Wilkommen %1$s, deine Anmeldung wurde verzögert, du kannst den Chat benutzen, sobald ein Moderator dich hereinlässt.',
	'waitreload' => 'Wenn diese Seite sich nicht alle %d Sekunden aktualisiert, benutze den Knopf unten, um die Seite manuell neu zu laden!',
	'reload' => 'Aktualisieren',
	'rules' => 'Regeln',
	'talkto' => 'Senden an',
	'toall' => 'Alle Teilnehmer',
	'tomem' => 'Nur Mitglieder',
	'tostaff' => 'Nur Moderatoren',
	'toadmin' => 'Nur Admins',
	'alsopurge' => 'Auch Nachrichten löschen',
	'dellast' => 'Letzte Nachricht löschen',
	'delall' => 'Alle Nachrichten löschen',
	'switchsingle' => 'Zu Einzel-Zeile wechseln',
	'switchmulti' => 'Zu Mehrfach-Zeilen wechseln',
	'help' => 'Hilfe',
	'helpguest' => 'Alle Funktionen sollten recht selbsterklärend sein, benutze einfach die Knöpfe. In deinem Profil kannst du die Aktualisierungsrate, Schriftfarbe und deine gewünschte Postboxgröße anpassen.<br><u>Hinweis:</u> Dies ist ein Chat, wenn du also nichts schreibst, wirst du automatisch nach einiger Zeit abgemaldet.',
	'helpembed' => 'Wenn du ein Bild einbetten möchtest, füge einfach ein [img] vor die Adresse deines Bildes. Beispiel: [img]http://example.com/images/file.jpg bettet das Bild in deinen Beitrag ein.',
	'helpmem' => 'Mitglieder: Du wirst einige zusätzliche Optionen in deinem Profil haben. Du kannst deine Schriftart ändern und du kannst dein Passwort jederzeit ändern.',
	'helpmod' => 'Moderatoren: Achte auf den Admin-Knof unten. Er bringt eine Seite auf, auf der du Nachrichten löschen kannst, Teilnehmer rausschmeißen kannst, alle aktive Sitzungen anzeigen lassen kannst und den Gastzugriff deaktivieren kannst, falls dies nötig sein sollte.',
	'helpadm' => 'Admins: Du wirst zusätzlich in der Lage sein Gäste zu registrieren, Mitglieder zu verwalten und neue Nicknanem zu registrieren, ohne dass sie im Raum sind.',
	'profile' => 'Dein Profil',
	'ignore' => 'Ignorieren',
	'unignore' => 'Nicht mehr ignorieren',
	'refreshrate' => 'Aktualisierungsrate (20-150 Sekunden)',
	'fontcolour' => 'Schriftfarbe',
	'viewexample' => 'Beispiele anzeigen',
	'bgcolour' => 'Hintergrundfarbe',
	'fontface' => 'Schriftart',
	'roomdefault' => 'Raumstandard',
	'bold' => 'Fett',
	'italic' => 'Kursiv',
	'fontexample' => 'Beispiel für deine gewählte Schrift',
	'timestamps' => 'Zeitstempel anzeigen',
	'embed' => 'Bilder einbetten',
	'incognito' => 'Inkognito Modus',
	'pbsize' => 'Postboxgröße',
	'nbsize' => 'Notizboxgröße',
	'width' => 'Breite:',
	'height' => 'Höhe:',
	'changepass' => 'Passwort ändern',
	'oldpass' => 'Altes Passwort:',
	'newpass' => 'Neues Passwort:',
	'confirmpass' => 'Passwort bestätigen:',
	'savechanges' => 'Änderungen speichern',
	'reloadpb' => 'Postbox neu laden',
	'reloadmsgs' => 'Nachrichten neu laden',
	'chgprofile' => 'Profil ändern',
	'adminbtn' => 'Admin',
	'admnotes' => 'Adminnotizen',
	'notes' => 'Notizen',
	'clone' => 'Klonen',
	'randh' => 'Regeln & Hilfe',
	'exit' => 'Chat verlassen',
	'bye' => 'Auf Wiedersehen %s, besuche uns bald wieder!',
	'colourtable' => 'Farbtabelle',
	'backtoprofile' => 'Zurück zu deinem Profil',
	'copy' => 'Kopiere:',
	'choosecol' => 'Gast, such dir eine Farbe aus:',
	'randomcol' => 'Zufällige Farbe',
	'enter' => 'Chat beitreten',
	'error' => 'Fehler:',
	'members' => 'Mitglieder:',
	'guests' => 'Gäste:',
	'approveguests' => '%d neue Gäste zum Hereinlassen',
	'allowchecked' => 'Ausgewählte erlauben',
	'allowall' => 'Alle erlauben',
	'denychecked' => 'Ausgewählte abweisen',
	'denyall' => 'Alle abweisen',
	'denymessage' => 'Nachricht an abgewiesene senden:',
	'butallowdeny' => 'Senden',
	'waitempty' => 'Keine weiteren Beitrittsanfragen zu akzeptieren.',
	'wrongcaptcha' => 'Falsches Captcha',
	'captchatime' => 'Captcha wurde bereits verwendet oder ist abgelaufen.',
	'noguests' => 'Entschuldigung, zur Zeit nur Mitglieder!',
	'curchat' => 'Zurzeit sind %d Teilnehmer im Raum:',
	'cantreg' => '%s kann nicht registriert werden',
	'alreadyreged' => '%s ist bereits registriert.',
	'successreg' => '%s wurde erfolgreich registriert.',
	'cantchgstat' => 'Der Status von %s kann nicht geändert werden.',
	'succdel' => '%s wurde erfolgriech aus der Datenbank gelöscht.',
	'succchg' => 'Status of %s successfully changed.',
	'wrongpass' => 'Falsches Passwort!',
	'succprofile' => 'Dein Profil wurde erfolgreich gespeichert.',
	'backtologin' => 'Zurück zur Anmeldeseite.',
	'backtochat' => 'Zurück zum Chat.',
	'Beige' => 'Beige',
	'Black' => 'Schwarz',
	'Blue' => 'Blau',
	'BlueViolet' => 'Blauviolett',
	'Brown' => 'Braun',
	'Cyan' => 'Türkis',
	'DarkBlue' => 'Dunkelblau',
	'DarkGreen' => 'Dunkelgrün',
	'DarkRed' => 'Dunkelrot',
	'DarkViolet' => 'Dunkelviolett',
	'DeepSkyBlue' => 'Himmelsblau',
	'Gold' => 'Gold',
	'Grey' => 'Grau',
	'Green' => 'Grün',
	'HotPink' => 'Pink',
	'Indigo' => 'Indigoblau',
	'LightBlue' => 'Hellblau',
	'LightGreen' => 'Hellgrün',
	'LimeGreen' => 'Lindgrün',
	'Magenta' => 'Magenta',
	'Olive' => 'Oliv',
	'Orange' => 'Orange',
	'OrangeRed' => 'Orangerot',
	'Purple' => 'Lila',
	'Red' => 'Rot',
	'RoyalBlue' => 'Königsblau',
	'SeaGreen' => 'Seegrün',
	'Sienna' => 'Siena',
	'Silver' => 'Silber',
	'Tan' => 'Hellbraun',
	'Teal' => 'Blaugrün',
	'Violet' => 'Violett',
	'White' => 'Weiß',
	'Yellow' => 'Gelb',
	'YellowGreen' => 'Gelbgrün',
	'contributors' => 'Mitwirkende'
);
?>
